@@ -472,7 +472,7 @@ class ResourceSet(object):
                     yield self._subject._rdf_to_python(self._predicate, o)
 
     def __lt__(self, other):
-        return self.any().__lt__(other.any())
+        return str(self.any()).__lt__(str(other.any()))
 
     def _matches_lang(self, o):
         return not self._lang or not isinstance(o, Literal) or o.language == self._lang or not o.language
